==> nextcloud-19.0.3.tgz: nextcloud/apps/password_policy/l10n/he.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "תוקף הססמה פג, נא להשתמש בשיטה שכחתי ססמה כדי לאפס",
    "Password must not have been used recently before." : "אסור להשתמש בססמה שכבר נעשה בה שימוש לאחרונה.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "הססמה היא בין מיליון הססמאות הנפוצות ביותר. נא להפוך אותה ליותר ייחודית.",
    "Password is present in compromised password list. Please choose a different password." : "הססמה מופיעה ברשימת הססמאות שנפרצו. נא לבחור בססמה חלופית.",
    "Password needs to be at least %s characters long" : "על הססמה להיות באורך של %s תווים לפחות",
    "Password needs to contain at least one numeric character." : "הססמה חייבת להכיל לפחות מספר כלשהו.",
    "Password needs to contain at least one special character." : "הססמה חייבת להכיל לפחות תו מיוחד אחד.",
    "Password needs to contain at least one lower and one upper case character." : "על הססמה להכיל לפחות אות אחת קטנה ואות אחת גדולה.",
    "Password policy" : "מדיניות ססמה",
    "Allows admins to configure a password policy" : "מאפשר למנהלים להגדיר מדיניות ססמה",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "לאפשר להנהלה להגדיר תנאי קדם מסוימים לססמה, למשל: לאסוף אורך מזערי",
    "Minimal length" : "אורך מזערי",
    "User password history" : "היסטוריית הססמאות של המשתמש",
    "days until user password expires" : "ימים עד לפקיעת תוקף ססמת המשתמש",
    "login attempts before the user account is blocked. (0 for no limit)" : "ניסיונות כניסה לפני חסימת חשבון המשתמש. (0 ללא הגבלה)",
    "Forbid common passwords" : "איסור על מילים נפוצות",
    "Enforce upper and lower case characters" : "אכיפת אותיות קטנות וגדולות",
    "Enforce numeric characters" : "אכיפת ספרות",
    "Enforce special characters" : "אכיפת תווים מיוחדים",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "לבדוק את הססמה מול רשימת ססמאות שדלפו אצל haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "בדיקה זו מייצרת גיבוב של הססמה ושולחת את 5 התווים הראשונים של הגיבוב הזה ל־API של haveibeenpwned.com כדי לקבל רשימה של כל הגיבובים שמתחילים בתווים האלה. לאחר מכן היא בודקת בעותק ה־Nextcloud אם גיבוב הססמה הוא במערך התוצאות."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-19.0.7.tgz: nextcloud/apps/password_policy/l10n/he.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "תוקף הססמה פג, נא להשתמש בשיטה שכחתי ססמה כדי לאפס",
    "Password must not have been used recently before." : "אסור להשתמש בססמה שכבר נעשה בה שימוש לאחרונה.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "הססמה היא בין מיליון הססמאות הנפוצות ביותר. נא להפוך אותה ליותר ייחודית.",
    "Password is present in compromised password list. Please choose a different password." : "הססמה מופיעה ברשימת הססמאות שנפרצו. נא לבחור בססמה חלופית.",
    "Password needs to be at least %s characters long" : "על הססמה להיות באורך של %s תווים לפחות",
    "Password needs to contain at least one numeric character." : "הססמה חייבת להכיל לפחות מספר כלשהו.",
    "Password needs to contain at least one special character." : "הססמה חייבת להכיל לפחות תו מיוחד אחד.",
    "Password needs to contain at least one lower and one upper case character." : "על הססמה להכיל לפחות אות אחת קטנה ואות אחת גדולה.",
    "Password policy" : "מדיניות ססמה",
    "Allows admins to configure a password policy" : "מאפשר למנהלים להגדיר מדיניות ססמה",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "לאפשר להנהלה להגדיר תנאי קדם מסוימים לססמה, למשל: לאסוף אורך מזערי",
    "User password history" : "היסטוריית הססמאות של המשתמש",
    "Forbid common passwords" : "איסור על מילים נפוצות",
    "Enforce upper and lower case characters" : "אכיפת אותיות קטנות וגדולות",
    "Enforce numeric characters" : "אכיפת ספרות",
    "Enforce special characters" : "אכיפת תווים מיוחדים",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "לבדוק את הססמה מול רשימת ססמאות שדלפו אצל haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "בדיקה זו מייצרת גיבוב של הססמה ושולחת את 5 התווים הראשונים של הגיבוב הזה ל־API של haveibeenpwned.com כדי לקבל רשימה של כל הגיבובים שמתחילים בתווים האלה. לאחר מכן היא בודקת בעותק ה־Nextcloud אם גיבוב הססמה הוא במערך התוצאות.",
    "Minimal length" : "אורך מזערי",
    "days until user password expires" : "ימים עד לפקיעת תוקף ססמת המשתמש",
    "login attempts before the user account is blocked. (0 for no limit)" : "ניסיונות כניסה לפני חסימת חשבון המשתמש. (0 ללא הגבלה)"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
